@@ -13,6 +13,7 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "dist": "district",
                        "dst": "district",
                        "d": "district",
+                       "p": "precinct",
                        "boro": "borough",
                        "twp": "township",
                        "tp": "township",
@@ -54,7 +55,7 @@ COMMON_REPLACEMENTS = {"pct": "precinct",
                        "eastern": "east",
                        "s":"south",
                        "southern": "south",
-                       "w":"west",
+                       # "w":"west",
                        "western": "west",
                        "i": "1",
                        "ii": "2",
@@ -88,7 +89,7 @@ class PrecinctMatcher:
         self.results: Dict[str, str] = {}
 
 
-    def default(self):
+    def default(self, n=6):
         """
         Default matching, with all the batteries included.
         """
@@ -96,7 +97,7 @@ class PrecinctMatcher:
         self.insensitive_normalized()
         self.insensitive_normalized(aggressive=True)
         if self.primary:
-            return self.weighted_manual()
+            return self.weighted_manual(n=n)
         else:
             return self.results
 
@@ -141,7 +142,8 @@ class PrecinctMatcher:
         if not acceptable: # shortcut
             return False
 
-        elif diff := set(primary.lower().split()).symmetric_difference(set(secondary.lower().split())):
+        elif set(primary.lower().split()).symmetric_difference(set(secondary.lower().split())):
+            diff = set(primary.lower().split()).symmetric_difference(set(secondary.lower().split()))
             # print(diff, primary, secondary)
             if diff.issubset(acceptable):
                 return True
@@ -262,7 +264,11 @@ class PrecinctMatcher:
                     continue
 
             primary_loc = normalized_primary.index(each_string)
-            secondary_loc = normalized_secondary.index(matches[match][0])
+            try:
+                secondary_loc = normalized_secondary.index(matches[match][0])
+            except IndexError as e:
+                print("Error", e)
+                return self.results
 
             if verbose:
                 print(f"Matched '{self.primary[primary_loc]}' with '{self.secondary[secondary_loc]}'.")
